/* addprofiledialogview.vala
 *
 * Copyright (C) 2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;
using Gee;

public class I4uc.GtkFrontend.AddProfileDialogView : Gtk.Dialog, I4uc.Core.AddProfileDialogView
{
	private Label _warning_message_label = new Label ("");
	private InfoBar _warning_message_info_bar = new InfoBar ();
	private RadioButton _new_profile_radio = new RadioButton.with_label (null, _("Create profile"));
	private CheckButton _is_public_profile_check = new CheckButton.with_label (_("Public profile"));
	private Entry _new_profile_entry = new Entry ();
	private RadioButton _import_profile_radio;
	private FileChooserButton _project_chooser = new FileChooserButton (_("Select project to import profile to current project"), FileChooserAction.OPEN);
	private ItemsCombo _profiles_combo = new ItemsCombo ();
	private Button _accept_button;

	public bool is_new { get { return _new_profile_radio.active; } }
	public bool is_public { get { return _is_public_profile_check.active; } }

	public string profile_name
	{
		owned get
		{
			if (this.is_new)
				return _new_profile_entry.text;
			return _profiles_combo.current_item;
		}
	}

	public string folder_uri
	{
		set { _project_chooser.set_current_folder_uri (value); }
		owned get { return _project_chooser.get_current_folder_uri (); }
	}

	public string project_uri
	{
		owned get { return _project_chooser.get_uri (); }
	}

	public string warning_message { set; get; }
	public bool warning_message_visible { set; get; }
	public bool new_profile_sensitive { set; get; }
	public bool import_project_sensitive { set; get; }
	public bool import_profile_sensitive { set; get; }
	public bool accept_sensitive { set; get; }
	
	public AddProfileDialogView ()
	{
		this.title = _("Add profile to project");

		var info_bar_content = _warning_message_info_bar.get_content_area () as Container;
		info_bar_content.add (_warning_message_label);
		this.vbox.pack_start (_warning_message_info_bar, false, false, 5);

		var label_size_group = new SizeGroup (SizeGroupMode.HORIZONTAL);
		var value_size_group = new SizeGroup (SizeGroupMode.HORIZONTAL);

		this.vbox.pack_start (_new_profile_radio, false, false, 5);

		var hbox = Utils.create_hbox (_("Profile name:"), label_size_group, this.vbox);
		hbox.pack_start (_new_profile_entry, true, true, 5);
		value_size_group.add_widget (_new_profile_entry);

		_import_profile_radio = new RadioButton.with_label_from_widget (_new_profile_radio, _("Import profile"));
		this.vbox.pack_start (_import_profile_radio, false, false, 5);

		hbox = Utils.create_hbox (_("Project:"), label_size_group, this.vbox);
		hbox.pack_start (_project_chooser, true, true, 5);
		value_size_group.add_widget (_project_chooser);
		var filter = new FileFilter ();
		filter.set_name (_("i4uc projects"));
		filter.add_pattern ("*.i4uc");
		_project_chooser.add_filter (filter);

		hbox = Utils.create_hbox (_("Profile:"), label_size_group, this.vbox);
		hbox.pack_start (_profiles_combo, true, true, 5);
		value_size_group.add_widget (_profiles_combo);
		
		_is_public_profile_check.active = true;
		this.vbox.pack_start (_is_public_profile_check, true, true, 5);

		add_button (STOCK_CANCEL, ResponseType.CANCEL);
		_accept_button = add_button (STOCK_OK, ResponseType.OK) as Button;
		set_default_response (ResponseType.OK);
		this.vbox.show_all ();
		
		//Bind properties
		bind_property ("warning-message", _warning_message_label, "label", BindingFlags.BIDIRECTIONAL);
		bind_property ("warning-message-visible", _warning_message_info_bar, "visible", BindingFlags.BIDIRECTIONAL);
		bind_property ("new-profile-sensitive", _new_profile_entry, "sensitive", BindingFlags.BIDIRECTIONAL);
		bind_property ("import-project-sensitive", _project_chooser, "sensitive", BindingFlags.BIDIRECTIONAL);
		bind_property ("import-profile-sensitive", _profiles_combo, "sensitive", BindingFlags.BIDIRECTIONAL);
		bind_property ("accept-sensitive", _accept_button, "sensitive", BindingFlags.BIDIRECTIONAL);
		
		//Connect signals
		_new_profile_radio.toggled.connect (() => this.is_new_changed ());
		_new_profile_entry.changed.connect (() => this.new_profile_changed ());
		_project_chooser.file_set.connect (() => this.import_project_changed ());
		_profiles_combo.notify["current-item"].connect (() => this.import_profile_changed ());
	}

	public void add_profiles (Collection<string> profiles)
	{
		foreach (var profile in profiles)
			_profiles_combo.add_item (profile);
	}

	public void clear_profiles_list ()
	{
		_profiles_combo.clear_list ();
	}

	public new I4uc.Core.DialogResponse run ()
	{
		return DialogResponses.get_dialog_response ((ResponseType)base.run ());
	}

	public new void close ()
	{
		base.close ();
	}
}
