/* app.vala
 *
 * Copyright (C) 2010-2011  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;
using Gee;

public class I4uc.GtkFrontend.App : GLib.Object, I4uc.Core.App
{
	private ViewFactory _view_factory = new ViewFactory ();
	
	private DocumentsView _documents_view;
	private MainWindowView _main_window_view = new MainWindowView ();
	private ProgrammersView _programmers_view;
	private ProjectsView _projects_view;
	
	private I4uc.Core.DocumentsLogic _documents_logic;
	private I4uc.Core.MainWindowLogic _main_window_logic;
	private I4uc.Core.ProgrammersLogic _programmers_logic;
	private I4uc.Core.ProjectsLogic _projects_logic;
	
	private I4uc.Core.Settings _settings = new I4uc.Core.Settings ();
	
	private HashMap<string, I4uc.Core.Builder> _builders = new HashMap<string, I4uc.Core.Builder> ();
	private HashMap<string, I4uc.Core.Programmer> _programmers = new HashMap<string, I4uc.Core.Programmer> ();
	
	public I4uc.Core.ViewFactory view_factory { get { return _view_factory; } }
	
	public I4uc.Core.DocumentsView documents_view { get { return _documents_view; } }
	public I4uc.Core.MainWindowView main_window_view { get { return _main_window_view; } }
	public I4uc.Core.ProgrammersView programmers_view { get { return _programmers_view; } }
	public I4uc.Core.ProjectsView projects_view { get { return _projects_view; } }
	
	public I4uc.Core.DocumentsLogic documents_logic { get { return _documents_logic; } }
	public I4uc.Core.MainWindowLogic main_window_logic { get { return _main_window_logic; } }
	public I4uc.Core.ProgrammersLogic programmers_logic { get { return _programmers_logic; } }
	public I4uc.Core.ProjectsLogic projects_logic { get { return _projects_logic; } }
	
	public I4uc.Core.Settings settings { get { return _settings; } }
	
	public Gee.Map<string, I4uc.Core.Builder> builders { get { return _builders; } }
	public Gee.Map<string, I4uc.Core.Programmer> programmers { get { return _programmers; } }
	
	public PageSetup page_setup { set; get; default = new PageSetup (); }
	public PrintSettings print_settings { set; get; default = new PrintSettings (); }
	
	public void load_all ()
	{
		_main_window_view.show_all ();
		
		var ui_manager = _main_window_view.ui_manager;
		var pages_panel = _main_window_view.pages_panel;
		var side_panel = _main_window_view.side_panel;
		var bottom_panel = _main_window_view.bottom_panel;
		
		_documents_view = new DocumentsView (ui_manager, pages_panel, side_panel, this);
		_projects_view = new ProjectsView (ui_manager, side_panel, bottom_panel);
		_programmers_view = new ProgrammersView (ui_manager, pages_panel, side_panel, bottom_panel);
		
		_main_window_logic = new I4uc.Core.MainWindowLogic (this);
		_documents_logic = new I4uc.Core.DocumentsLogic (this);
		_programmers_logic = new I4uc.Core.ProgrammersLogic (this);
		_projects_logic = new I4uc.Core.ProjectsLogic (this);
	}
	
	public void add_recent (string uri)
	{
		RecentManager.get_default ().add_item (uri);
	}
}
