/* builderslist.vala
 *
 * Copyright (C) 2010-2011  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;

public class I4uc.GtkFrontend.BuildersList : Gtk.VBox, I4uc.Core.BuildersList
{
	private ItemsCombo _builders_combo = new ItemsCombo (_("Builder:"));
	private ItemsCombo _output_types_combo = new ItemsCombo (_("Output type:"));
	private ItemsCombo _devices_combo = new ItemsCombo (_("Device:"));
	private Expander _compile_options_expander = new Expander ("<b>" + _("Compile options") + "</b>");
	private OptionsView _compile_options_view = new OptionsView ();
	private OptionsView _link_options_view = new OptionsView ();
	
	public string current_builder { set; get; }
	public string current_output_type { set; get; }
	public string current_device { set; get; }
	public I4uc.Core.OptionsView compile_options_view { get { return _compile_options_view; } }
	public I4uc.Core.OptionsView link_options_view { get { return _link_options_view; } }
	
	public bool compile_options_visible { set; get; }
	
	public BuildersList ()
	{
		// Prepare compile options
		var scrolled_window = new ScrolledWindow (null, null);
		scrolled_window.add_with_viewport (_compile_options_view);
		scrolled_window.set_policy (PolicyType.NEVER, PolicyType.AUTOMATIC);
		
		_compile_options_expander.use_markup = true;
		_compile_options_expander.add (scrolled_window);
		
		// Prepare link options
		scrolled_window = new ScrolledWindow (null, null);
		scrolled_window.add_with_viewport (_link_options_view);
		scrolled_window.set_policy (PolicyType.NEVER, PolicyType.AUTOMATIC);
		
		var expander = new Expander ("<b>" + _("Link options") + "</b>");
		expander.use_markup = true;
		expander.add (scrolled_window);
		
		// Pack widgets
		pack_start (_builders_combo, false, false, 2);
		pack_start (_output_types_combo, false, false, 2);
		pack_start (_devices_combo, false, false, 2);
		pack_start (_compile_options_expander, true, true, 2);
		pack_start (expander, true, true, 2);
		
		//Bind properties
		bind_property ("current-builder", _builders_combo, "current-item", BindingFlags.BIDIRECTIONAL);
		bind_property ("current-output-type", _output_types_combo, "current-item", BindingFlags.BIDIRECTIONAL);
		bind_property ("current-device", _devices_combo, "current-item", BindingFlags.BIDIRECTIONAL);
		bind_property ("compile-options-visible", _compile_options_expander, "visible", BindingFlags.BIDIRECTIONAL);
	}

	public void add_builder (string builder)
	{
		_builders_combo.add_item (builder);
	}

	public void add_output_type (string output_type)
	{
		_output_types_combo.add_item (output_type);
	}

	public void add_device (string device)
	{
		_devices_combo.add_item (device);
	}

	public void clear_builders_list ()
	{
		_builders_combo.clear_list ();
	}

	public void clear_output_types_list ()
	{
		_output_types_combo.clear_list ();
	}

	public void clear_devices_list ()
	{
		_devices_combo.clear_list ();
	}
}
