/* fileslist.vala
 *
 * Copyright (C) 2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;
using Gee;

public class I4uc.GtkFrontend.FilesList : Gtk.VBox
{
	private ListStore _files_store;
	private TreeView _files_view;
	
	private ArrayList<string> _files = new ArrayList<string> ();
	
	private enum FilesColumns
	{
		ICON,
		FILE,
		N_COLUMNS
	}
	
	public string current_file
	{
		set
		{
			if (_files.size == 0)
				return;
			TreeIter iter;
			_files_store.get_iter_from_string (out iter, _files.index_of (value).to_string ());
			_files_view.get_selection ().select_iter (iter);
		}
		get
		{
			TreeIter iter;
			unowned string file = null;
			if (_files_view.get_selection ().get_selected (null, out iter))
				_files_store.get (iter, FilesColumns.FILE, out file);
			return file;
		}
	}

	public signal void file_changed ();
	public signal void file_activated ();
	
	public FilesList ()
	{
		_files_store = new ListStore (FilesColumns.N_COLUMNS, typeof (string), typeof (string));
		_files_view = new TreeView.with_model (_files_store);
		
		var column = new TreeViewColumn ();
		CellRenderer renderer = new CellRendererPixbuf ();
 		column.pack_start (renderer, false);
		column.add_attribute (renderer, "stock-id", FilesColumns.ICON);
		renderer = new CellRendererText ();
 		column.pack_start (renderer, false);
		column.add_attribute (renderer, "text", FilesColumns.FILE);
		_files_view.append_column (column);
		_files_view.set_headers_visible (false);
		
		pack_start (_files_view, true, true, 0);
		
		_files_view.get_selection ().changed.connect (() => this.file_changed ());
		_files_view.row_activated.connect (() => this.file_activated ());
	}
	
	public void add_file (string file)
	{
		if (file in _files)
			return;
		TreeIter iter;
		_files_store.append (out iter);
		_files_store.set (iter, FilesColumns.ICON, STOCK_FILE, FilesColumns.FILE, file);
		_files.add (file);
	}
	
	public void remove_file (string file)
	{
		if (!(file in _files))
			return;
		TreeIter iter;
		_files_store.get_iter_from_string (out iter, _files.index_of (file).to_string ());
		_files_store.remove (iter);
		_files.remove (file);
	}
	
	public void clear_list ()
	{
		_files.clear ();
		_files_store.clear ();
	}
}
