/* logpage.vala
 *
 * Copyright (C) 2009-2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;

public class I4uc.GtkFrontend.LogPage : Page, I4uc.Core.LogPage
{
	private ListStore _log_store;
	private TreeView _log_view;
	
	private enum Columns
	{
		COLUMN_1,
		N_COLUMNS
	}
	
	public LogPage ()
	{
		var clear_button = new Button.from_stock (STOCK_CLEAR);
		
		var buttons_vbox = new VBox (false, 0);
		buttons_vbox.pack_start (clear_button, false, false, 5);
		
		_log_store = new ListStore (Columns.N_COLUMNS, typeof (string));
		_log_view = new TreeView.with_model (_log_store);
		
		var renderer = new CellRendererText ();
		var column = new TreeViewColumn ();
 		column.pack_start (renderer, false);
		column.add_attribute (renderer, "markup", Columns.COLUMN_1);
		_log_view.append_column (column);
		
		var scrolled_window = new ScrolledWindow (null, null);
		scrolled_window.add (_log_view);
		scrolled_window.set_policy (PolicyType.AUTOMATIC, PolicyType.AUTOMATIC);

		var hbox = new HBox (false, 0);
		hbox.pack_start (scrolled_window, true, true, 5);
		hbox.pack_start (buttons_vbox, false, false, 5);
		
		pack_start (hbox, true, true, 5);
		show_all ();
		
		//Connect signals
		clear_button.clicked.connect (() => clear ());
		_log_view.row_activated.connect (on_row_activated);
	}
	
	public void add_message (string message)
	{
		TreeIter iter;
		_log_store.append (out iter);
		_log_store.set (iter, Columns.COLUMN_1, message);
		_log_view.scroll_to_cell (_log_store.get_path (iter), null, true, 0, 1);
	}
	
	public void clear ()
	{
		_log_store.clear ();
	}
	
	private void on_row_activated (TreePath path)
	{
		TreeIter iter;
		string message;
		_log_store.get_iter (out iter, path);
		_log_store.get (iter, Columns.COLUMN_1, out message);
		this.message_activated (message);
	}
}
