/* profilebuilderlogpage.vala
 *
 * Copyright (C) 2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;

public class I4uc.GtkFrontend.ProfileBuilderLogPage : Page, I4uc.Core.ProfileBuilderLogPage
{
	private ListStore _log_store;
	private TreeView _log_view;
	
	public string message_format { set; get; }
	public string error_format { set; get; }
	public string command_format { set; get; }
	public string output_format { set; get; }
	
	private enum Columns
	{
		MESSAGE_WITH_FORMAT,
		MESSAGE,
		COMMAND_CONTEXT,
		N_COLUMNS
	}
	
	public ProfileBuilderLogPage ()
	{
		var clear_button = new Button.from_stock (STOCK_CLEAR);
		
		var buttons_vbox = new VBox (false, 0);
		buttons_vbox.pack_start (clear_button, false, false, 5);
		
		_log_store = new ListStore (Columns.N_COLUMNS, typeof (string), typeof (string), typeof (I4uc.Core.CommandContext));
		_log_view = new TreeView.with_model (_log_store);
		_log_view.can_focus = false;
		
		var renderer = new CellRendererText ();
		var column = new TreeViewColumn ();
 		column.pack_start (renderer, false);
		column.add_attribute (renderer, "markup", Columns.MESSAGE_WITH_FORMAT);
		_log_view.append_column (column);
		
		var scrolled_window = new ScrolledWindow (null, null);
		scrolled_window.add (_log_view);
		scrolled_window.set_policy (PolicyType.AUTOMATIC, PolicyType.AUTOMATIC);

		var hbox = new HBox (false, 0);
		hbox.pack_start (scrolled_window, true, true, 5);
		hbox.pack_start (buttons_vbox, false, false, 5);
		
		pack_start (hbox, true, true, 5);
		show_all ();
		
		//Connect signals
		clear_button.clicked.connect (() => clear ());
		_log_view.row_activated.connect (on_row_activated);
	}
	
	public void add_message (string message)
	{
		TreeIter iter;
		_log_store.append (out iter);
		_log_store.set (iter, Columns.MESSAGE_WITH_FORMAT, _message_format.printf (message),
		                      Columns.MESSAGE, message);
		_log_view.scroll_to_cell (_log_store.get_path (iter), null, true, 0, 1);
	}
	
	public void add_error (string error)
	{
		TreeIter iter;
		_log_store.append (out iter);
		_log_store.set (iter, Columns.MESSAGE_WITH_FORMAT, _error_format.printf (error),
		                      Columns.MESSAGE, error);
		_log_view.scroll_to_cell (_log_store.get_path (iter), null, true, 0, 1);
	}
	
	public void add_command (I4uc.Core.CommandContext command_context)
	{
		TreeIter iter;
		_log_store.append (out iter);
		_log_store.set (iter, Columns.MESSAGE_WITH_FORMAT, _command_format.printf (command_context.command),
		                      Columns.MESSAGE, command_context.command,
		                      Columns.COMMAND_CONTEXT, command_context);
		foreach (var output in command_context.output.split ("\n"))
		{
			// Don't show empty lines
			if (output == "")
				continue;
			// Remove carry return if the line has it
			if (output.has_suffix ("\r"))
				output = output[0:-1];
			_log_store.append (out iter);
			_log_store.set (iter, Columns.MESSAGE_WITH_FORMAT, _output_format.printf (output),
			                      Columns.MESSAGE, output,
			                      Columns.COMMAND_CONTEXT, command_context);
		}
		_log_view.scroll_to_cell (_log_store.get_path (iter), null, true, 0, 1);
	}
	
	public void clear ()
	{
		_log_store.clear ();
	}
	
	private void on_row_activated (TreePath path)
	{
		TreeIter iter;
		string message;
		I4uc.Core.CommandContext command_context = null;
		_log_store.get_iter (out iter, path);
		_log_store.get (iter, Columns.MESSAGE, out message,
		                      Columns.COMMAND_CONTEXT, out command_context);
		if (command_context == null)
			this.message_activated (message);
		else
			this.command_activated (message, command_context);
	}
}
