/* profiledialogview.vala
 *
 * Copyright (C) 2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;

public class I4uc.GtkFrontend.ProfileDialogView : Gtk.Dialog, I4uc.Core.ProfileDialogView
{
	private Label _warning_message_label = new Label ("");
	private InfoBar _warning_message_info_bar = new InfoBar ();
	private Entry _profile_name_entry = new Entry ();
	private CheckButton _is_public_profile_check = new CheckButton.with_label (_("Public profile"));
	private ItemsCheckList _files_check_list = new ItemsCheckList ();
	private Button _accept_button;
	
	public string profile_name { set; owned get; }
	public bool is_public { set; get; }
	
	public Gee.List<string> activated_files { owned get { return _files_check_list.activated_items; } }
	
	public string warning_message { set; get; }
	public bool warning_message_visible { set; get; }
	public bool accept_sensitive { set; get; }
	
	public ProfileDialogView ()
	{
		var info_bar_content = _warning_message_info_bar.get_content_area () as Container;
		info_bar_content.add (_warning_message_label);
		
		var notebook = new Notebook ();
		
		//Profile general settings
		var vbox = new VBox (false, 0);
		vbox.border_width = 2;
		
		Utils.add_vbox_label (vbox, _("Profile name:"), _profile_name_entry);
		
		vbox.pack_start (_is_public_profile_check, true, true, 5);
		
		notebook.append_page (vbox, null);
		notebook.set_tab_label_text (vbox, _("General settings"));
		
		//Profile files
		vbox = new VBox (false, 0);
		vbox.border_width = 2;
		
		vbox.pack_start (_files_check_list, true, true, 0);
		
		notebook.append_page (vbox, null);
		notebook.set_tab_label_text (vbox, _("Files"));
		
		add_button (STOCK_CANCEL, ResponseType.CANCEL);
		_accept_button = add_button (STOCK_OK, ResponseType.OK) as Button;
		set_default_response (ResponseType.OK);
		
		this.vbox.pack_start (_warning_message_info_bar, false, false, 5);
		this.vbox.pack_start (notebook, true, true, 0);
		this.vbox.show_all ();
		
		//Bind properties
		bind_property ("profile-name", _profile_name_entry, "text", BindingFlags.BIDIRECTIONAL);
		bind_property ("is-public", _is_public_profile_check, "active", BindingFlags.BIDIRECTIONAL);
		bind_property ("warning-message", _warning_message_label, "label", BindingFlags.BIDIRECTIONAL);
		bind_property ("warning-message-visible", _warning_message_info_bar, "visible", BindingFlags.BIDIRECTIONAL);
		bind_property ("accept-sensitive", _accept_button, "sensitive", BindingFlags.BIDIRECTIONAL);
	}
	
	public void add_file (string file, bool active)
	{
		_files_check_list.add_item (file, active);
	}
	
	public new I4uc.Core.DialogResponse run ()
	{
		return DialogResponses.get_dialog_response ((ResponseType)base.run ());
	}
	
	public new void close ()
	{
		base.close ();
	}
}
