/* syntaxhighlightmenu.vala
 *
 * Copyright (C) 2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;
using Gee;

public class I4uc.GtkFrontend.SyntaxHighlightMenu : GLib.Object, I4uc.Core.SyntaxHighlightMenu
{
	private UIManager _ui_manager;
	private Gtk.ActionGroup _action_group;
	private string _language_id;
	
	public string language_id
	{
		set
		{
			var action = _action_group.get_action (value);
			_language_id = value;
			(action as RadioAction).active = true;
		}
		get { return _language_id; }
	}
	
	public SyntaxHighlightMenu (UIManager ui_manager, Gtk.ActionGroup action_group)
	{
		_ui_manager = ui_manager;
		_action_group = action_group;
		
		var action = new RadioAction ("none", _("Plain text"), _("Disable syntax highlighting"), null, -1);
		action.active = true;
		_language_id = "none";
		action.activate.connect (on_action_changed);
		
		unowned SList group = action.get_group ();
		_action_group.add_action (action);
		var merge_id = _ui_manager.new_merge_id ();
		_ui_manager.add_ui (merge_id,
		                    "/MainMenu/ViewMenu/ViewMenuOps/SyntaxHighlightMenu",
		                    "none",
		                    "none",
		                    UIManagerItemType.MENUITEM,
		                    true);
		foreach (var source_language in list_source_languages ())
		{
			action = new RadioAction (source_language.id, source_language.name, null, null, -1);
			action.activate.connect (on_action_changed);
			action.set_group (group);
			group = action.get_group ();
			_action_group.add_action (action);
			merge_id = _ui_manager.new_merge_id ();
			_ui_manager.add_ui (merge_id,
								"/MainMenu/ViewMenu/ViewMenuOps/SyntaxHighlightMenu",
								source_language.id,
								source_language.id,
								UIManagerItemType.MENUITEM,
								false);
		}
	}
	
	private void on_action_changed (Gtk.Action action)
	{
		if ((action as RadioAction).active)
		{
			_language_id = action.name;
			this.language_id_changed;
		}
	}
	
	private Gee.List<unowned SourceLanguage> list_source_languages ()
	{
		var language_manager = SourceLanguageManager.get_default ();
		var source_languages = new ArrayList<unowned SourceLanguage> ();
		
		foreach (var language_id in language_manager.get_language_ids ())
			source_languages.add (language_manager.get_language (language_id));
		
		for (int i=0; i<source_languages.size-1; i++)
			for (int j=i+1; j<source_languages.size; j++)
				if (source_languages[i].name > source_languages[j].name)
				{
					var temp = source_languages[i];
					source_languages[i] = source_languages[j];
					source_languages[j] = temp;
				}
		
		return source_languages.read_only_view;
	}
}
