/* viewfactory.vala
 *
 * Copyright (C) 2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gee;
using Gtk;

public class I4uc.GtkFrontend.ViewFactory : GLib.Object, I4uc.Core.ViewFactory
{
	public void show_error_message (string error_message)
	{
		var message = new MessageDialog (null, DialogFlags.MODAL, MessageType.ERROR, ButtonsType.NONE, error_message);
		message.add_button (STOCK_OK, ResponseType.OK);
		message.set_default_response (ResponseType.OK);
		message.run ();
		message.destroy ();
	}
	
	public void show_open_dialog (ref string folder_uri, out Gee.List<string> files_to_open)
	{
		var dialog = new FileChooserDialog (_("Open"), null, FileChooserAction.OPEN);
		dialog.select_multiple = true;
		dialog.local_only = false;
		dialog.set_current_folder_uri (folder_uri);
		dialog.add_button (STOCK_CANCEL, ResponseType.CANCEL);
		dialog.add_button (STOCK_OPEN, ResponseType.OK);
		dialog.set_default_response (ResponseType.OK);
		var filter = new FileFilter ();
		filter.set_name (_("All files"));
		filter.add_pattern ("*");
		dialog.add_filter (filter);
		
		var uris = new ArrayList<string> ();
		if (dialog.run () == ResponseType.OK)
		{
			folder_uri = dialog.get_current_folder_uri ();
			foreach (var uri in dialog.get_uris ())
				uris.add (uri);
		}
		files_to_open = uris.read_only_view;
		dialog.destroy ();
	}
	
	public I4uc.Core.DialogResponse show_save_dialog (string name, ref string folder_uri, out string file_uri)
	{
		var dialog = new FileChooserDialog (_("Save as"), null, FileChooserAction.SAVE);
		dialog.local_only = false;
		dialog.set_current_name (name);
		dialog.set_current_folder_uri (folder_uri);
		dialog.add_button (STOCK_CANCEL, ResponseType.CANCEL);
		dialog.add_button (STOCK_SAVE, ResponseType.OK);
		dialog.set_default_response (ResponseType.OK);
		dialog.do_overwrite_confirmation = true;
		var response = dialog.run ();
		file_uri = dialog.get_uri ();
		folder_uri = dialog.get_current_folder_uri ();
		dialog.destroy ();
		return DialogResponses.get_dialog_response ((ResponseType)response);
	}
	
	public I4uc.Core.DialogResponse show_yes_no_message (string message, bool cancel=false)
	{
		var dialog = new MessageDialog (null, DialogFlags.MODAL, MessageType.WARNING, ButtonsType.NONE, message);
		if (cancel)
			dialog.add_button (STOCK_CANCEL, ResponseType.CANCEL);
		dialog.add_button (STOCK_NO, ResponseType.NO);
		dialog.add_button (STOCK_YES, ResponseType.YES);
		dialog.set_default_response (ResponseType.YES);
		var response = dialog.run ();
		dialog.destroy ();
		return DialogResponses.get_dialog_response ((ResponseType)response);
	}
}
