/* addfiledialoglogic.vala
 *
 * Copyright (C) 2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gee;

public class I4uc.Core.AddFileDialogLogic : GLib.Object
{
	private AddFileDialogView _view;
	private Project _project;

	public AddFileDialogLogic (AddFileDialogView view, Project project)
	{
		_view = view;
		_project = project;

		//Configure view
		_view.file_in_project_visible = false;
		_view.accept_sensitive = false;
		_view.folder_uri = project.folder_uri;
		_view.add_profiles (project.profiles.keys);

		//Connect view signals
		_view.is_new_changed.connect (on_is_new_changed);
		_view.new_file_changed.connect (on_new_file_changed);
		_view.import_file_changed.connect (on_import_file_changed);
	}

	public bool run ()
	{
		if (_view.run () == DialogResponse.CANCEL)
			return false;
		return true;
	}
	
	private void on_is_new_changed ()
	{
		_view.new_file_sensitive = _view.is_new;
		_view.import_file_sensitive = !_view.is_new;
		if (_view.is_new)
			on_new_file_changed ();
		else
			on_import_file_changed ();
	}

	private void on_new_file_changed ()
	{
		_view.accept_sensitive = !(_view.filename == "" ||
		                           _view.filename.has_prefix (".") ||
		                           _view.filename in _project.files);
		_view.file_in_project_visible = _view.filename in _project.files;
	}

	private void on_import_file_changed ()
	{
		if (_view.filename == "" || _view.filename == null)
		{
			_view.accept_sensitive = false;
			return;
		}

		var import_file = File.new_for_uri (_view.filename);
		var import_file_folder_uri = import_file.get_parent ().get_uri ();
		var file_info = import_file.query_info (FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME, FileQueryInfoFlags.NONE, null);
		var import_filename = file_info.get_display_name ();

		var file_in_project = import_file_folder_uri == _project.folder_uri && (import_filename in _project.files);
		_view.accept_sensitive = !(import_filename.has_prefix (".") || file_in_project);
		_view.file_in_project_visible = file_in_project;
	}
}
