/* builder.vala
 *
 * Copyright (C) 2010-2011  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gee;

public class I4uc.Core.SourceType : GLib.Object
{
	private ArrayList<string> _clean_types = new ArrayList<string> ();
	private ArrayList<string> _command_required_options = new ArrayList<string> ();
	private ArrayList<string> _command_optional_options = new ArrayList<string> ();
	private ArrayList<Option> _options = new ArrayList<Option> ();
	
	public string name { set; get; }
	public string input_type { set; get; }
	public string output_type { set; get; }
	public Gee.List<string> clean_types { get { return _clean_types; } }
	public string command_format { set; get; }
	public Gee.List<string> command_required_options { get { return _command_required_options; } }
	public Gee.List<string> command_optional_options { get { return _command_optional_options; } }
	public string command_regex { set; get; default=""; }
	public Gee.List<Option> options { get { return _options; } }
}

public class I4uc.Core.OutputCommand : GLib.Object
{
	private ArrayList<string> _required_options = new ArrayList<string> ();
	private ArrayList<string> _optional_options = new ArrayList<string> ();
	
	public string format { set; get; }
	public Gee.List<string> required_options { get { return _required_options; } }
	public Gee.List<string> optional_options { get { return _optional_options; } }
	public string regex { set; get; default=""; }
}

public class I4uc.Core.OutputType : GLib.Object
{
	private ArrayList<string> _clean_types = new ArrayList<string> ();
	private ArrayList<OutputCommand> _commands = new ArrayList<OutputCommand> ();
	private ArrayList<Option> _options = new ArrayList<Option> ();
	
	public string name { set; get; }
	public string output_type { set; get; }
	public Gee.List<string> clean_types { get { return _clean_types; } }
	public Gee.List<OutputCommand> commands { get { return _commands; } }
	public Gee.List<Option> options { get { return _options; } }
}

public class I4uc.Core.Builder : GLib.Object
{
	private ArrayList<string> _devices = new ArrayList<string> ();
	private HashMap<string, SourceType> _source_types = new HashMap<string, SourceType> ();
	private HashMap<string, OutputType> _output_types = new HashMap<string, OutputType> ();
	
	public string name { set; get; }
	public Gee.List<string> devices { get { return _devices; } }
	public Gee.Map<string, SourceType> source_types { get { return _source_types; } }
	public Gee.Map<string, OutputType> output_types { get { return _output_types; } }

	public SourceType? get_source_type_from_filename (string filename)
	{
		foreach (var source_type in _source_types.values)
			if (filename.has_suffix (source_type.input_type))
				return source_type;
		return null;
	}
}
