/* documentpageview.vala
 *
 * Copyright (C) 2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */

public interface I4uc.Core.DocumentPageView : GLib.Object, Page
{
	//Settings properties
	public abstract string font_name { set; get; }
	public abstract uint tab_width { set; get; }
	public abstract bool auto_indent { set; get; }
	public abstract bool highlight_current_line { set; get; }
	public abstract bool insert_spaces_instead_of_tabs { set; get; }
	public abstract bool show_line_numbers { set; get; }
	public abstract bool highlight_matching_brackets { set; get; }
	public abstract bool wrap_mode { set; get; }
	public abstract bool can_undo { get; }
	public abstract bool can_redo { get; }
	public abstract bool has_selection { get; }
	public abstract string content { set; owned get; }
	public abstract string language_id { set; get; }
	
	public abstract MessageBar error_message_bar { get; }
	public abstract MessageBar reload_message_bar { get; }
	public abstract MessageBar save_message_bar { get; }
	
	//Search and Replace properties
	public abstract SearchBarView search_bar_view { get; }
	public abstract bool search_bar_view_visible { set; get; }
	
	//Content properties
	public abstract bool content_visible { set; get; }
	public abstract bool content_modified { set; get; }
	
	//Signals
	public signal void selected ();
	public signal void content_changed ();
	public signal void modified_changed ();
	public signal void selection_changed ();
	public signal void focused_in ();
	
	//Methods
	public abstract void undo ();
	public abstract void redo ();
	public abstract void cut ();
	public abstract void copy ();
	public abstract void paste ();
	public abstract void guess_language_id (string content_type);
	public abstract void show_print_dialog () throws GLib.Error;
	public abstract DialogResponse show_close_message ();
	public abstract void grab_focus ();
	public abstract void go_to_line (int line);
}
