/* documentpreferencespagelogic.vala
 *
 * Copyright (C) 2010-2011  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gee;

public class I4uc.Core.DocumentPreferencesPageLogic : GLib.Object
{
	private App _app;
	private DocumentPreferencesPageView _view;
	private Gee.List<DocumentPageLogic> _page_logics;
	
	public DocumentPreferencesPageView view { get { return _view; } }
	
	public DocumentPreferencesPageLogic (App app, Gee.List<DocumentPageLogic> page_logics)
	{
		_app = app;
		_view = _app.documents_view.preferences_page_view;
		_page_logics = page_logics;
		
		_view.tab_title = _("Preferences");
		
		//configure view
		_view.font_name = _app.settings.font;
		_view.tab_width = _app.settings.tab_width;
		_view.auto_indent = _app.settings.auto_indent;
		_view.highlight_current_line = _app.settings.highlight_current_line;
		_view.insert_spaces_instead_of_tabs = _app.settings.insert_spaces_instead_of_tabs;
		_view.show_line_numbers = _app.settings.show_line_numbers;
		_view.highlight_matching_brackets = _app.settings.highlight_matching_brackets;
		_view.wrap_mode = _app.settings.wrap_mode;
		
		//connect view signals
		_view.notify["font-name"].connect (on_preferences_changed);
		_view.notify["tab-width"].connect (on_preferences_changed);
		_view.notify["auto-indent"].connect (on_preferences_changed);
		_view.notify["highlight-current-line"].connect (on_preferences_changed);
		_view.notify["insert-spaces-instead-of-tabs"].connect (on_preferences_changed);
		_view.notify["show-line-numbers"].connect (on_preferences_changed);
		_view.notify["highlight-matching-brackets"].connect (on_preferences_changed);
		_view.notify["wrap-mode"].connect (on_preferences_changed);
	}
	
	private void on_preferences_changed ()
	{
		foreach (var page_logic in _page_logics)
		{
			page_logic.view.font_name = _view.font_name;
			page_logic.view.tab_width = _view.tab_width;
			page_logic.view.auto_indent = _view.auto_indent;
			page_logic.view.highlight_current_line = _view.highlight_current_line;
			page_logic.view.insert_spaces_instead_of_tabs = _view.insert_spaces_instead_of_tabs;
			page_logic.view.show_line_numbers = _view.show_line_numbers;
			page_logic.view.highlight_matching_brackets = _view.highlight_matching_brackets;
			page_logic.view.wrap_mode = _view.wrap_mode;
		}
		
		_app.settings.font = _view.font_name;
		_app.settings.tab_width = _view.tab_width;
		_app.settings.auto_indent = _view.auto_indent;
		_app.settings.highlight_current_line = _view.highlight_current_line;
		_app.settings.insert_spaces_instead_of_tabs = _view.insert_spaces_instead_of_tabs;
		_app.settings.show_line_numbers = _view.show_line_numbers;
		_app.settings.highlight_matching_brackets = _view.highlight_matching_brackets;
		_app.settings.wrap_mode = _view.wrap_mode;
	}
}
