/* mainwindowlogic.vala
 *
 * Copyright (C) 2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gee;

public class I4uc.Core.MainWindowLogic : GLib.Object
{
	private App _app;
	private MainWindowView _view;
	
	public MainWindowLogic (App app)
	{
		_app = app;
		_view = _app.main_window_view;
		
		//Configure view
		_view.title = _("IDE for microcontrollers");
		_view.show_side_panel_active = _app.settings.side_panel_visible;
		_view.side_panel_visible = _app.settings.side_panel_visible;
		_view.show_bottom_panel_active = _app.settings.bottom_panel_visible;
		_view.bottom_panel_visible = _app.settings.bottom_panel_visible;
		_view.set_size (_app.settings.width, _app.settings.height);
		if (_app.settings.maximized)
			_view.maximize ();
		
		//Connect view signals
		_view.size_changed.connect (on_size_changed);
		_view.state_changed.connect (on_state_changed);
		_view.show_side_panel_changed.connect (on_show_side_panel_changed);
		_view.show_bottom_panel_changed.connect (on_show_bottom_panel_changed);
		_view.about_clicked.connect (on_about_clicked);
	}
	
	private void on_size_changed (int width, int height)
	{
		_app.settings.width = width;
		_app.settings.height = height;
	}
	
	private void on_state_changed (bool maximized)
	{
		_app.settings.maximized = maximized;
	}

	private void on_show_side_panel_changed ()
	{
		_view.side_panel_visible = _view.show_side_panel_active;
		_app.settings.side_panel_visible = _view.show_side_panel_active;
	}
	
	private void on_show_bottom_panel_changed ()
	{
		_view.bottom_panel_visible = _view.show_bottom_panel_active;
		_app.settings.bottom_panel_visible = _view.show_bottom_panel_active;
	}
	
	private void on_about_clicked ()
	{
		var app_info = new HashMap<string, string> ();
		app_info["program_name"] = Config.PACKAGE;
		app_info["comments"] = _("IDE for microcontrollers");
		app_info["version"] = Config.VERSION;
		app_info["copyright"] = "Copyright (C) 2009-2011  Matias De la Puente";
		app_info["website"] = "http://trac.usla.org.ar/i4uc/";
		var authors = new ArrayList<string> ();
		authors.add ("Matias De la Puente <mfpuente.ar@gmail.com>");
		_view.show_about_dialog (app_info, authors);
	}
}
