/* programmer.vala
 *
 * Copyright (C) 2010-2011  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gee;

public class I4uc.Core.Programmer : GLib.Object
{
	private ArrayList<string> _firmware_types = new ArrayList<string> ();
	private HashMap<string, string> _description = new HashMap<string, string> ();
	private ArrayList<Option> _options = new ArrayList<Option> ();
	private HashMap<string, Gee.List<string>> _required_options = new HashMap<string, Gee.List<string>> ();
	private HashMap<string, Gee.List<string>> _optional_options = new HashMap<string, Gee.List<string>> ();
	private string _lang;
	
	public string name { set; get; }
	public bool can_write_flash { set; get; }
	public bool can_read_flash { set; get; }
	public bool can_verify_flash { set; get; }
	public bool can_erase_flash { set; get; }
	public bool can_write_fuses { set; get; }
	public bool can_read_fuses { set; get; }
	public bool can_get_version { set; get; }
	
	public string write_flash_command { set; get; }
	public string read_flash_command { set; get; }
	public string verify_flash_command { set; get; }
	public string erase_flash_command { set; get; }
	public string write_fuses_command { set; get; }
	public string read_fuses_command { set; get; }
	public string get_version_command { set; get; }
	
	public Gee.List<string> firmware_types { get { return _firmware_types; } }
	public Gee.Map<string, string> description { get { return _description; } }
	public Gee.List<Option> options { get { return _options; } }
	public Gee.Map<string, Gee.List<string>> required_options { get { return _required_options; } }
	public Gee.Map<string, Gee.List<string>> optional_options { get { return _optional_options; } }
	
	public string locale_description
	{
		owned get
		{
			if (_lang == null)
			{
				_lang = "en";
				foreach (var lang in Intl.get_language_names ())
					if (_description.has_key (lang))
						_lang = lang;
			}
			return _description[_lang];
		}
	}
	
	public bool is_valid_firmware_type (string filename)
	{
		foreach (var firmware_type in _firmware_types)
			if (filename.has_suffix (firmware_type))
				return true;
		return false;
	}
}

public class I4uc.Core.ProgrammerSettings : GLib.Object
{
	private HashMap<string, OptionSettings> _options = new HashMap<string, OptionSettings> ();
	
	public string name { set; get; }
	public Gee.Map<string, OptionSettings> options { get { return _options; } }
	
	public string to_xml (string prefix)
	{
		var xml_str = prefix + "<programmer name=\"%s\">\n".printf (_name);
		foreach (var option_settings in _options.values)
			xml_str += prefix + option_settings.to_xml ("\t");
		xml_str += prefix + "</programmer>\n";
		return xml_str;
	}
}
