/* searchbarlogic.vala
 *
 * Copyright (C) 2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */

public class I4uc.Core.SearchBarLogic : GLib.Object
{
	private SearchBarView _view;
	
	public SearchBarLogic (SearchBarView view)
	{
		_view = view;
		
		//configure view
		_view.search_text = "";
		_view.replace_text = "";
		_view.search_backward_sensitive = false;
		_view.search_forward_sensitive = false;
		_view.replace_sensitive = false;
		_view.replace_all_sensitive = false;
		_view.highlight_all = true;
		
		//connect view signals
		_view.notify["search-text"].connect (on_search_text_changed);
		_view.search_backward_clicked.connect (() => _view.search (false));
		_view.search_forward_clicked.connect (() => _view.search (true));
		_view.notify["highlight-all"].connect (on_highlight_all_changed);
		_view.notify["match-case"].connect (on_search_text_changed);
		_view.notify["replace-text"].connect (on_replace_text_changed);
		_view.replace_clicked.connect (() => _view.replace ());
		_view.replace_all_clicked.connect (() => _view.replace_all ());
	}
	
	private void on_search_text_changed ()
	{
		if (_view.highlight_all)
		{
			_view.remove_highlight ();
			if (_view.search_text != null && _view.search_text != "")
				_view.apply_highlight ();
		}
		update_ui ();
	}
	
	private void on_highlight_all_changed ()
	{
		if (_view.highlight_all && _view.search_text != null && _view.search_text != "")
			_view.apply_highlight ();
		else
			_view.remove_highlight ();
	}
	
	private void on_replace_text_changed ()
	{
		update_ui ();
	}
	
	private void update_ui ()
	{
		var valid_search_text = _view.search_text != null && _view.search_text != "";
		var valid_replace_text = _view.replace_text != null && _view.replace_text != "";
		
		_view.search_backward_sensitive = valid_search_text;
		_view.search_forward_sensitive = valid_search_text;
		_view.replace_sensitive = valid_search_text && valid_replace_text;
		_view.replace_all_sensitive = valid_search_text && valid_replace_text;
	}
}
